@@ -6,15 +6,17 @@ package render_test
 import (
 	"testing"
 
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestRoleBindingRender(t *testing.T) {
 	c := render.RoleBinding{}
-	r := render.NewRow(6)
+	r := model1.NewRow(6)
 
-	assert.NoError(t, c.Render(load(t, "rb"), "", &r))
+	require.NoError(t, c.Render(load(t, "rb"), "", &r))
 	assert.Equal(t, "default/blee", r.ID)
-	assert.Equal(t, render.Fields{"default", "blee", "blee", "SvcAcct", "fernand"}, r.Fields[:5])
+	assert.Equal(t, model1.Fields{"default", "blee", "blee", "SvcAcct", "fernand"}, r.Fields[:5])
 }
